@@ -6,5 +6,7 @@ DEFAULT_NAMESPACE_NAME = 'default'
 DEFAULT_MARQUEZ_URL = 'http://localhost:8080'
 DEFAULT_LIMIT = 100
 DEFAULT_OFFSET = 0
+DEFAULT_DEPTH = 20
+DEFAULT_WITH_DOWNSTREAM = False
 
 API_PATH_V1 = '/api/v1'
